# Changelog

## 0.2.1 (2025-06-13)

### Code Refactoring

* migrate to modular architecture ([87fb729](https://github.com/btraven00/denet/commit/87fb7292126da6bbad99734a8eedf99882297bdc))

## 0.2.0 (2025-06-12)


### Features

* add cli utility ([8f4525a](https://github.com/btraven00/denet/commit/8f4525accd7e0917c75d714e62c3b0f645c6e611))
* add execution summary ([cf605da](https://github.com/btraven00/denet/commit/cf605da17d865951583cad0998c55269df512ae9))
* attach to PID ([edf962a](https://github.com/btraven00/denet/commit/edf962aca1375ee695f480405913d90ebfe43972))
* child process monitoring ([fd6f444](https://github.com/btraven00/denet/commit/fd6f444a7e6884b5c199565bd6fb6bbce374e9f3))
* improve CPU measurement accuracy with direct procfs integration ([acac9c1](https://github.com/btraven00/denet/commit/acac9c1c6bce1606400643fa20a4e9e1d3d1805f))
* improve python API ([4ba1006](https://github.com/btraven00/denet/commit/4ba10063e28f0909c99f049e3e35bca1b6c25a8b))
* improve terminal output ([35eb029](https://github.com/btraven00/denet/commit/35eb0291c3eed658ba8213963dc4c9bd93348384))
* metadata separation ([6d0533d](https://github.com/btraven00/denet/commit/6d0533d33c8c0d517baf8f152b0c0b182a8b65aa))
* separate i/o from start of process ([27e24bc](https://github.com/btraven00/denet/commit/27e24bce7cf6c285f480770272f617b31b8db477))
* split network and disk i/o ([f8f3d53](https://github.com/btraven00/denet/commit/f8f3d53c2b8b568363e83164ab57dc4fbcc0ca03))


### Bug Fixes

* account for delta io in children tree ([b9ec550](https://github.com/btraven00/denet/commit/b9ec5507819adbc0168216651bae99d91bfa4a71))
